@@ -39,7 +39,6 @@ _main_window_geometry = {
 
 
 class MainWindow(QMainWindow):
-
     signal_fitting_parameters_changed = Signal()
 
     def __init__(self, *, gpc):
@@ -83,7 +82,6 @@ class MainWindow(QMainWindow):
         gpc.param_model.parameters_changed()
 
     def initialize(self):
-
         self.resize(_main_window_geometry["initial_width"], _main_window_geometry["initial_height"])
 
         self.setMinimumWidth(_main_window_geometry["min_width"])
@@ -336,6 +334,13 @@ class MainWindow(QMainWindow):
         )
 
         # Quantitative calibration changed
+        self.wnd_load_quantitative_calibration.signal_quantitative_calibration_changed.connect(
+            self.central_widget.right_panel.tab_plot_xrf_maps.update_combo_quant_ref
+        )
+        self.wnd_load_quantitative_calibration.signal_quantitative_calibration_changed.connect(
+            self.central_widget.right_panel.tab_plot_rgb_maps.update_combo_quant_ref
+        )
+
         self.wnd_load_quantitative_calibration.signal_quantitative_calibration_changed.connect(
             self.central_widget.right_panel.tab_plot_rgb_maps.slot_update_ranges
         )
