@@ -14,7 +14,6 @@ logger = logging.getLogger(__name__)
 
 
 class FitMapsWidget(FormBaseWidget):
-
     # Signal that is sent (to main window) to update global state of the program
     update_global_state = Signal()
     computations_complete = Signal(object)
@@ -40,7 +39,6 @@ class FitMapsWidget(FormBaseWidget):
         self.initialize()
 
     def initialize(self):
-
         v_spacing = global_gui_parameters["vertical_spacing_in_tabs"]
 
         self._setup_settings()
@@ -306,6 +304,8 @@ class FitMapsWidget(FormBaseWidget):
         dlg.scaler_sel = params["scaler_sel"]
         dlg.interpolate_on = params["interpolate_on"]
         dlg.quant_norm_on = params["quant_norm_on"]
+        dlg.quant_ref_eline_list = params["quant_ref_eline_list"]
+        dlg.quant_ref_eline = params["quant_ref_eline"]
 
         res = dlg.exec()
         if res:
@@ -315,6 +315,7 @@ class FitMapsWidget(FormBaseWidget):
                 scaler_name = dlg.get_selected_scaler_name()
                 interpolate_on = dlg.interpolate_on
                 quant_norm_on = dlg.quant_norm_on
+                quant_ref_eline = dlg.quant_ref_eline
                 file_formats = []
                 if dlg.save_tiff:
                     file_formats.append("tiff")
@@ -326,6 +327,7 @@ class FitMapsWidget(FormBaseWidget):
                     scaler_name=scaler_name,
                     interpolate_on=interpolate_on,
                     quant_norm_on=quant_norm_on,
+                    quant_ref_eline=quant_ref_eline,
                     file_formats=file_formats,
                 )
                 if file_formats:
