@@ -110,7 +110,6 @@ class GlobalProcessingClasses:
         return self.io_model.is_databroker_available()
 
     def open_data_file(self, file_path):
-
         self.io_model.data_ready = False
         # only load one file
         # 'temp' is used to reload the same file, otherwise file_name will not update
@@ -618,6 +617,12 @@ class GlobalProcessingClasses:
     def set_maps_quant_norm_enabled(self, enable):
         self.img_model_adv.enable_quantitative_normalization(enable)
 
+    def get_maps_quant_ref_eline(self):
+        return self.img_model_adv.quantitative_ref_eline
+
+    def set_maps_quant_ref_eline(self, ref_eline):
+        self.img_model_adv.set_quantitative_ref_eline(ref_eline)
+
     def get_maps_scale_opt(self):
         """Returns selected plot type: `Linear` or `Log`"""
         return self.img_model_adv.scale_opt
@@ -820,6 +825,12 @@ class GlobalProcessingClasses:
     def set_rgb_maps_quant_norm_enabled(self, enable):
         self.img_model_rgb.enable_quantitative_normalization(enable)
 
+    def get_rgb_maps_quant_ref_eline(self):
+        return self.img_model_rgb.quantitative_ref_eline
+
+    def set_rgb_maps_quant_ref_eline(self, ref_eline):
+        self.img_model_rgb.set_quantitative_ref_eline(ref_eline)
+
     def compute_rgb_map_ranges(self):
         self.img_model_rgb.set_low_high_value()
 
@@ -833,6 +844,9 @@ class GlobalProcessingClasses:
     def load_quantitative_calibration_data(self, file_path):
         self.img_model_adv.load_quantitative_calibration_data(file_path)
 
+    def get_quant_calibration_active_lines(self):
+        return self.img_model_adv.param_quant_analysis.get_active_emission_lines()
+
     def get_quant_calibration_data(self):
         return self.img_model_adv.param_quant_analysis.calibration_data
 
@@ -1023,7 +1037,6 @@ class GlobalProcessingClasses:
         return params
 
     def set_general_fitting_params(self, params):
-
         # Another option is self.param_model.param_new
         dest_dict = self.param_model.param_new
 
@@ -1250,7 +1263,6 @@ class GlobalProcessingClasses:
         self.fitting_parameters_changed()
 
     def load_parameters_from_file(self, parameter_file_path, incident_energy_from_param_file=None):
-
         try:
             self.param_model.read_param_from_file(parameter_file_path)
         except Exception as ex:
@@ -1266,7 +1278,6 @@ class GlobalProcessingClasses:
             param_incident_energy = self.param_model.param_new["coherent_sct_energy"]["value"]
 
             if self.io_model.incident_energy_available:
-
                 # Incident energy from datafile metadata
                 mdata_incident_energy = self.io_model.scan_metadata.get_mono_incident_energy()
 
@@ -1290,7 +1301,6 @@ class GlobalProcessingClasses:
                         overwrite_metadata_incident_energy = bool(incident_energy_from_param_file)
 
             else:
-
                 # If incident energy is not present in file metadata, then
                 #   just load the incident energy from the parameter file.
                 overwrite_metadata_incident_energy = True
@@ -1660,7 +1670,6 @@ class GlobalProcessingClasses:
             self.plot_model.update_fit_plots()
 
     def total_spectrum_fitting(self):
-
         # Update parameter for fit. This may be unnecessary
         self.apply_to_fit(update_plots=False)
 
@@ -1833,7 +1842,6 @@ class GlobalProcessingClasses:
         return self.fit_model.param_quant_estimation.get_suggested_json_fln()
 
     def get_displayed_quant_calib_parameters(self):
-
         fluorescence_data_dict = self.fit_model.param_quant_estimation.fluorescence_data_dict
         if fluorescence_data_dict is None:
             raise RuntimeError("Attempt to obtain quantitative standard parameters while no standard is selected")
@@ -1894,6 +1902,8 @@ class GlobalProcessingClasses:
         scalers, scaler_sel = self.get_maps_scaler_list()
         interpolate_on = self.get_maps_grid_interpolate()
         quant_norm_on = self.get_maps_quant_norm_enabled()
+        quant_ref_eline = self.get_maps_quant_ref_eline()
+        quant_ref_eline_list = self.get_quant_calibration_active_lines()
 
         return {
             "dset_list": dataset_list,
@@ -1902,10 +1912,20 @@ class GlobalProcessingClasses:
             "scaler_sel": scaler_sel,
             "interpolate_on": interpolate_on,
             "quant_norm_on": quant_norm_on,
+            "quant_ref_eline": quant_ref_eline,
+            "quant_ref_eline_list": quant_ref_eline_list,
         }
 
     def export_xrf_maps(
-        self, *, results_path, dataset_name, scaler_name, interpolate_on, quant_norm_on, file_formats
+        self,
+        *,
+        results_path,
+        dataset_name,
+        scaler_name,
+        interpolate_on,
+        quant_norm_on,
+        quant_ref_eline,
+        file_formats,
     ):
         # We don't want to make any changes to 'param_quant_analysis' at the original location
         #   This is a temporary copy.
@@ -1920,6 +1940,7 @@ class GlobalProcessingClasses:
                 scaler_name=scaler_name,
                 interpolate_on=interpolate_on,
                 quant_norm_on=quant_norm_on,
+                quant_ref_eline=quant_ref_eline,
                 param_quant_analysis=param_quant_analysis,
                 file_format=file_format,
             )
