@@ -102,6 +102,10 @@ class DrawImageAdvanced(Atom):
     # Variable that indicates whether quanitative normalization should be applied to data
     #   Associated with 'Quantitative' checkbox
     quantitative_normalization = Bool(False)
+    # The name of the emision line used for quantitative normalization. If "", then
+    #   quantitative normalization is applied only to the emission lines with calibration.
+    #   Assoicated with the respective combobox.
+    quantitative_ref_eline = Str()
 
     # The following fields are used for storing parameters used for quantitative analysis
     param_quant_analysis = Typed(object)
@@ -287,7 +291,6 @@ class DrawImageAdvanced(Atom):
             return self.scaler_items[self.scaler_name_index - 1]
 
     def set_scaler_index(self, scaler_index):
-
         self.scaler_name_index = scaler_index
 
         if self.scaler_name_index == 0:
@@ -396,6 +399,25 @@ class DrawImageAdvanced(Atom):
         self.set_low_high_value()  # reset low high values based on normalization
         self.show_image()
 
+    def set_quantitative_ref_eline(self, ref_eline):
+        """
+        Set emission line used as a reference for quantitative normalization. If empty string,
+        then calibration is performed only for emission lines with existing calibration.
+        """
+        ref_eline = str(ref_eline) if (ref_eline is not None) else ""
+        if not self.param_quant_analysis.get_eline_calibration(ref_eline):
+            ref_eline = ""
+        self.quantitative_ref_eline = ref_eline
+
+        # Propagate current value of 'self.param_quant_analysis' (activate 'observer' functions)
+        # TODO: the following may not be not needed in the view of the current framework
+        tmp = self.param_quant_analysis
+        self.param_quant_analysis = ParamQuantitativeAnalysis()
+        self.param_quant_analysis = tmp
+
+        self.set_low_high_value()  # reset low high values based on normalization
+        self.show_image()
+
     def set_plot_scatter(self, is_scatter):
         self.scatter_show = is_scatter
         self.show_image()
@@ -443,7 +465,6 @@ class DrawImageAdvanced(Atom):
         self.range_dict.clear()
 
         for data_name in self.dict_to_plot.keys():
-
             if self.quantitative_normalization:
                 # Quantitative normalization
                 data_arr, _ = self.param_quant_analysis.apply_quantitative_normalization(
@@ -451,6 +472,7 @@ class DrawImageAdvanced(Atom):
                     scaler_dict=self.scaler_norm_dict,
                     scaler_name_default=self.get_selected_scaler_name(),
                     data_name=data_name,
+                    ref_name=self.quantitative_ref_eline,
                     name_not_scalable=self.name_not_scalable,
                 )
             else:
@@ -614,7 +636,6 @@ class DrawImageAdvanced(Atom):
             grid.cbar_axes[i].set_visible(False)
 
         for i, k in enumerate(selected_keys):
-
             quant_norm_applied = False
             if self.quantitative_normalization:
                 # Quantitative normalization
@@ -623,6 +644,7 @@ class DrawImageAdvanced(Atom):
                     scaler_dict=self.scaler_norm_dict,
                     scaler_name_default=self.get_selected_scaler_name(),
                     data_name=k,
+                    ref_name=self.quantitative_ref_eline,
                     name_not_scalable=self.name_not_scalable,
                 )
             else:
@@ -635,7 +657,6 @@ class DrawImageAdvanced(Atom):
                 )
 
             if pixel_or_pos_local or scatter_show_local:
-
                 # xd_min, xd_max, yd_min, yd_max = min(self.x_pos), max(self.x_pos),
                 #     min(self.y_pos), max(self.y_pos)
                 x_pos_2D = self.io_model.img_dict["positions"]["x_pos"]
@@ -656,7 +677,6 @@ class DrawImageAdvanced(Atom):
                     yd_min, yd_max, yd_axis_min, yd_axis_max = yd_max, yd_min, yd_axis_max, yd_axis_min
 
             else:
-
                 yd, xd = data_arr.shape
 
                 xd_min, xd_max, yd_min, yd_max = 0, xd, 0, yd
@@ -691,7 +711,6 @@ class DrawImageAdvanced(Atom):
                 low_limit -= dv
 
             if self.scale_opt == "Linear":
-
                 if not scatter_show_local:
                     if grid_interpolate_local:
                         data_arr, _, _ = grid_interpolate(
@@ -751,7 +770,6 @@ class DrawImageAdvanced(Atom):
                 # axis.label.set_text("$[a.u.]$")
 
             else:
-
                 # maxz = np.max(data_arr)
                 # Set some reasonable minimum range for the colorbar
                 #   Zeros or negative numbers will be shown in white
