@@ -106,6 +106,10 @@ class DrawImageRGB(Atom):
     # Variable that indicates whether quanitative normalization should be applied to data
     #   Associated with 'Quantitative' checkbox
     quantitative_normalization = Bool(False)
+    # The name of the emision line used for quantitative normalization. If "", then
+    #   quantitative normalization is applied only to the emission lines with calibration.
+    #   Assoicated with the respective combobox.
+    quantitative_ref_eline = Str()
 
     rgb_name_list = List()  # List of names for RGB channels printed on the plot
 
@@ -241,7 +245,6 @@ class DrawImageRGB(Atom):
             return self.scaler_items[self.scaler_name_index - 1]
 
     def set_scaler_index(self, scaler_index):
-
         self.scaler_name_index = scaler_index
 
         if self.scaler_name_index == 0:
@@ -288,13 +291,25 @@ class DrawImageRGB(Atom):
         self.set_low_high_value()  # reset low high values based on normalization
         self.show_image()
 
+    def set_quantitative_ref_eline(self, ref_eline):
+        """
+        Set emission line used as a reference for quantitative normalization. If empty string,
+        then calibration is performed only for emission lines with existing calibration.
+        """
+        ref_eline = str(ref_eline) if (ref_eline is not None) else ""
+        if not self.img_model_adv.param_quant_analysis.get_eline_calibration(ref_eline):
+            ref_eline = ""
+        self.quantitative_ref_eline = ref_eline
+
+        self.set_low_high_value()  # reset low high values based on normalization
+        self.show_image()
+
     def set_low_high_value(self):
         """Set default low and high values based on normalization for each image."""
         # do not apply scaler norm on not scalable data
         self.range_dict.clear()
 
         for data_name in self.dict_to_plot.keys():
-
             if self.quantitative_normalization:
                 # Quantitative normalization
                 data_arr, _ = self.img_model_adv.param_quant_analysis.apply_quantitative_normalization(
@@ -302,6 +317,7 @@ class DrawImageRGB(Atom):
                     scaler_dict=self.scaler_norm_dict,
                     scaler_name_default=self.get_selected_scaler_name(),
                     data_name=data_name,
+                    ref_name=self.quantitative_ref_eline,
                     name_not_scalable=self.name_not_scalable,
                 )
             else:
@@ -378,6 +394,7 @@ class DrawImageRGB(Atom):
                     scaler_dict=self.scaler_norm_dict,
                     scaler_name_default=self.get_selected_scaler_name(),
                     data_name=k,
+                    ref_name=self.quantitative_ref_eline,
                     name_not_scalable=self.name_not_scalable,
                 )
             else:
@@ -505,7 +522,6 @@ class DrawImageRGB(Atom):
             return c_min, c_max
 
         if pixel_or_pos_local:
-
             # xd_min, xd_max, yd_min, yd_max = min(self.x_pos), max(self.x_pos),
             #     min(self.y_pos), max(self.y_pos)
             x_pos_2D = self.io_model.img_dict["positions"]["x_pos"]
@@ -576,7 +592,6 @@ class DrawImageRGB(Atom):
             return (data - data_min) / c_norm if (c_norm != 0) else (data - data_min)
 
         def _stretch_range(data_in, v_low, v_high):
-
             # 'data is already normalized, so that the values are in the range 0..1
             # v_low, v_high are in the range 0..100
             if data_in is None:
