@@ -138,7 +138,6 @@ class FileIOModel(Atom):
     incident_energy_set = Float(0.0)
 
     def __init__(self, *, working_directory):
-
         working_directory = os.path.abspath(os.path.expanduser(working_directory))
 
         self.file_directory = working_directory
@@ -555,7 +554,6 @@ class FileIOModel(Atom):
 
     @observe(str("file_opt"))
     def choose_file(self, change):
-
         if not self.data_ready:
             return
 
@@ -871,7 +869,6 @@ class DataSelection(Atom):
         return self.raw_data.shape
 
     def _get_sum(self, *, client=None):
-
         # Only the values of 'mask', 'pos1' and 'pos2' will be cached
         mask = self.mask if self.mask_active else None
         pt_start = self.sel_pt_start if self.selection_active else None
@@ -1030,7 +1027,6 @@ class SpectrumCalculator(object):
 
 
 def load_data_from_hdf5(working_directory, file_name, load_each_channel=True):
-
     get_data_nsls2 = True  # Only 'APS' format is currently used
     try:
         if get_data_nsls2 is True:
@@ -1172,6 +1168,7 @@ def output_data(
     use_average=False,
     dataset_name=None,
     quant_norm=False,
+    quant_ref_eline="",
     param_quant_analysis=None,
     positions_dict=None,
     interpolate_to_uniform_grid=False,
@@ -1202,6 +1199,11 @@ def output_data(
         should end with the suffix '_fit' (for sum of all channels), '_det1_fit" etc.
     quant_norm : bool
         True - quantitative normalization is enabled, False - disabled
+    quant_ref_eline: str
+        Reference emission line for quantitative calibration, e.g. 'Cu_K'. Apply quantitative
+        normalization only to the lines with existing calibration data if ``quant_ref_eline=""``
+        (emtpy string, default).
+
     param_quant_analysis : ParamQuantitativeAnalysis
         reference to class, which contains parameters for quantitative normalization
     interpolate_to_uniform_grid : bool
@@ -1282,6 +1284,7 @@ def output_data(
         name_append="",
         scaler_name=scaler_name,
         quant_norm=quant_norm,
+        quant_ref_eline=quant_ref_eline,
         param_quant_analysis=param_quant_analysis,
         use_average=use_average,
         scaler_name_list=scaler_name_list,
@@ -1297,6 +1300,7 @@ def output_data_to_tiff(
     scaler_name=None,
     scaler_name_list=None,
     quant_norm=False,
+    quant_ref_eline="",
     param_quant_analysis=None,
     use_average=False,
 ):
@@ -1321,6 +1325,10 @@ def output_data_to_tiff(
         The list of names of scalers that may exist in the dataset 'dataset_dict'
     quant_norm : bool
         True - apply quantitative normalization, False - use normalization by scaler
+    quant_ref_eline: str
+        Reference emission line for quantitative calibration, e.g. 'Cu_K'. Apply quantitative
+        normalization only to the lines with existing calibration data if ``quant_ref_eline=""``
+        (emtpy string, default).
     param_quant_analysis : ParamQuantitativeAnalysis
         reference to class, which contains parameters for quantitative normalization,
         if None, then quantitative normalization will be skipped
@@ -1350,7 +1358,6 @@ def output_data_to_tiff(
     def _save_data(
         data, *, output_dir, file_name, name_prefix_detector, name_append, file_format, scaler_name_list
     ):
-
         # The 'file_format' is specified as file extension
         file_extension = file_format.lower()
 
@@ -1379,6 +1386,7 @@ def output_data_to_tiff(
                     scaler_dict=fit_output,
                     scaler_name_default=None,  # We don't want data to be scaled
                     data_name=data_name,
+                    ref_name=quant_ref_eline,
                     name_not_scalable=None,
                 )  # For simplicity, all saved maps are normalized
                 if quant_norm_applied:
@@ -1495,7 +1503,6 @@ def read_hdf_APS(
         dict_sc = {}
 
     with h5py.File(file_path, "r+") as f:
-
         # Retrieve metadata if it exists
         if "xrfmap/scan_metadata" in f:  # Metadata is always loaded
             metadata = f["xrfmap/scan_metadata"]
@@ -1806,7 +1813,6 @@ def read_MAPS(working_directory, file_name, channel_num=1):
     print("file path is {}".format(file_path))
 
     with h5py.File(file_path, "r+") as f:
-
         data = f["MAPS"]
         fname = file_name.split(".")[0]
 
