@@ -264,7 +264,6 @@ class Fit1D(Atom):
         self.dict_to_plot = change["value"]
 
     def update_selected_index(self, selected_element=None, element_list_new=None):
-
         if selected_element is None:
             # Currently selected element
             element = self.selected_element
@@ -875,6 +874,7 @@ class Fit1D(Atom):
         scaler_name=None,
         interpolate_on=None,
         quant_norm_on=None,
+        quant_ref_eline="",
         param_quant_analysis=None,
         file_format="tiff",
     ):
@@ -893,6 +893,11 @@ class Fit1D(Atom):
             turns interpolation of images to uniform grid ON or OFF
         quant_norm_on: bool
             turns quantitative normalization of images on or off
+        quant_ref_eline: str
+            Reference emission line for quantitative calibration, e.g. 'Cu_K'. Apply quantitative
+            normalization only to the lines with existing calibration data if ``quant_ref_eline=""``
+            (emtpy string, default).
+
         param_quant_analysis: ParamQuantitativeAnalysis
             class that contains methods for quantitative normalization
         file_format: str
@@ -942,6 +947,7 @@ class Fit1D(Atom):
             interpolate_to_uniform_grid=interpolate_on,
             dataset_name=dataset_name,
             quant_norm=quant_norm_on,
+            quant_ref_eline=quant_ref_eline,
             param_quant_analysis=param_quant_analysis,
             dataset_dict=dataset_dict,
             positions_dict=positions_dict,
@@ -1650,7 +1656,6 @@ def residual_nonlinear_fit(pars, x, data=None, reg_mat=None):
 
 
 def fit_pixel_nonlinear_per_line(row_num, data, x0, param, reg_mat, use_snip):  # c_weight, fit_num, ftol):
-
     # c_weight = 1
     # fit_num = 100
     # ftol = 1e-3
@@ -1741,7 +1746,6 @@ def fit_pixel_multiprocess_nonlinear(data, x, param, reg_mat, use_snip=False):
 
 
 def get_area_and_error_nonlinear_fit(elist, fit_results, reg_mat):
-
     mat_sum = np.sum(reg_mat, axis=0)
     area_dict = OrderedDict()
     error_dict = OrderedDict()
